Index: chrome/common/chrome_paths.cc |
diff --git a/chrome/common/chrome_paths.cc b/chrome/common/chrome_paths.cc |
index 0758f1ee8e4dc6730f45fcfe541384a52292acba..7f223cf7b094ecfbf2142b8fb15322f12bcdaac7 100644 |
--- a/chrome/common/chrome_paths.cc |
+++ b/chrome/common/chrome_paths.cc |
@@ -53,8 +53,10 @@ const FilePath::CharType kInternalNaClPluginFileName[] = |
#endif |
#if defined(OS_POSIX) && !defined(OS_MACOSX) |
// File name of the nacl_helper, Linux only. |
const FilePath::CharType kInternalNaClHelperFileName[] = |
+ FILE_PATH_LITERAL("nacl_helper"); |
+const FilePath::CharType kInternalNaClHelperBootstrapFileName[] = |
FILE_PATH_LITERAL("nacl_helper_bootstrap"); |
#endif |
@@ -246,6 +248,11 @@ bool PathProvider(int key, FilePath* result) { |
return false; |
cur = cur.Append(kInternalNaClHelperFileName); |
break; |
+ case chrome::FILE_NACL_HELPER_BOOTSTRAP: |
+ if (!PathService::Get(base::DIR_MODULE, &cur)) |
+ return false; |
+ cur = cur.Append(kInternalNaClHelperBootstrapFileName); |
+ break; |
#endif |
case chrome::FILE_RESOURCES_PACK: |
#if defined(OS_MACOSX) |
@@ -53,8 +53,10 @@ const FilePath::CharType kInternalNaClPluginFileName[] = |
#endif |
#if defined(OS_POSIX) && !defined(OS_MACOSX) |
-// File name of the nacl_helper, Linux only. |
+// File name of the nacl_helper and nacl_helper_bootstrap, Linux only. |
const FilePath::CharType kInternalNaClHelperFileName[] = |